<?php 
    get_header(); 
    
    // redux option name
    global $gfxpartner_slope; 
    
    // determine if sidebar should be displayed or not, sidebar will appear by default
    $show_sidebar_archive = true;
    if (isset($gfxpartner_slope['show_sidebar_archive'])) {
        $show_sidebar_archive = $gfxpartner_slope['show_sidebar_archive'];
    }
    
    // determine sidebar location. default is on the right side
    $archive_sidebar_location = '2';
    if (isset($gfxpartner_slope['archive_sidebar_location'])) {
        $archive_sidebar_location = $gfxpartner_slope['archive_sidebar_location'];
    }

    // determine the corresponding bootstrap column for the content of the page
    $content_column = 'col-lg-8';
    // layout option for the blog post. default is list-1
    $post_layout = 'list';

    // if sidebar is not showing then
    if (!is_active_sidebar('archive-sidebar')) {
        $content_column = 'col';
        $post_layout = 'grid';
    }

    $show_excerpt = true;
    // if excerpt is to be shown, change post layout variable
    if (isset($gfxpartner_slope['show_excerpt_archive'])) {
        $show_excerpt = $gfxpartner_slope['show_excerpt_archive'];
    }

    if ($show_excerpt) {
        $post_layout .= '-1';
    }

    $content_class = 'content-column';
    if ($show_sidebar_archive && $archive_sidebar_location == '1' && is_active_sidebar('archive-sidebar')) {
        $content_class .= ' left-sidebar';
    } else if ($show_sidebar_archive && $archive_sidebar_location == '2' && is_active_sidebar('archive-sidebar')) {
        $content_class .= ' right-sidebar';
    }
  
?>

<div class="search-result sidebar-page">
    <div class="container">
        <?php if ( have_posts() ): ?>
            <div class="row">
                <div class="col-lg-8">
                    <div class="page-title">
                        <h5 class="heading heading-small light-2">
                            <?php echo esc_html__('CURRENTLY BROWSING:', 'slope') ?>
                        </h5>
                        <h1 class="heading heading-large dark-1">
                            <span><?php the_archive_title(); ?></span>
                        </h1>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div class="row">
            <div class="col-lg-12">
                <div class="search-result--inner">
                    <?php if ( have_posts() ): ?>
                        <div class="container">
                            <div class="row">
                                <?php
                                        // display sidebar on the left side
                                        if (
                                            $show_sidebar_archive && 
                                            $archive_sidebar_location == '1' && 
                                            is_active_sidebar('archive-sidebar')
                                        ):
                                    ?>
                                        <!--
                                        left sidebar - start
                                        -->
                                        <div class="col-lg-4 sidebar-column">
                                            <div class="sidebar-column-wrapper">
                                                <ul class="widget widget-container">
                                                    <?php dynamic_sidebar( 'archive-sidebar'); ?>
                                                </ul>
                                            </div>
                                        </div>
                                        <!--
                                        left sidebar - end
                                        -->
                                <?php endif; // ending - left sidebar condition ?>

                                <div class="<?php echo esc_attr($content_column); ?>">
                                    <div class="<?php echo esc_attr( $content_class ); ?>">
                                        <div class="blog-list">
                                            <div class="container">
                                                <div class="blog-list-container">
                                                    <div class="row">
                                                    <!--
                                                    posts - start
                                                    -->
                                                    <?php 

                                                        if( have_posts() ) : 
                                                            while( have_posts() ) {
                                                                the_post();

                                                                // get single post
                                                                get_template_part('inc/template/part', 'post', array(
                                                                    'id' => get_the_ID(),
                                                                    'blog_layout' => $post_layout
                                                                ));
                                                            } 
                                                            
                                                            // restore $post global 
                                                            wp_reset_postdata();         
                                                    ?> 
                                                    <!--
                                                    posts - end
                                                    -->
                                                        <?php
                                                            if ( !empty( get_previous_posts_link() ) || !empty( get_next_posts_link() ) ):
                                                        ?>
                                                        <!--
                                                        post pagination - start
                                                        -->
                                                        <div class="col-lg-11 <?php echo esc_attr($post_layout == 'list-1-left' ? 'offset-lg-1': ''); ?>">
                                                            <div class="pagination-container">
                                                                <?php 
                                                                    $args =  array(
                                                                        'base'         => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
                                                                        'total'        => $wp_query->max_num_pages,
                                                                        'current'      => max( 1, get_query_var( 'paged' ) ),
                                                                        'format'       => '?paged=%#%',
                                                                        'show_all'     => false,
                                                                        'type'         => 'list',
                                                                        'end_size'     => 2,
                                                                        'mid_size'     => 1,
                                                                        'prev_next'    => false,
                                                                        'add_args'     => false,
                                                                        'add_fragment' => '',
                                                                    ) ;
                                                                    echo paginate_links($args); 
                                                                ?>
                                                            </div>
                                                        </div>
                                                        <!--
                                                        post pagination - end
                                                        -->
                                                        <?php endif; ?>
                                                    <?php else: ?>
                                                        <div class="col-lg-11 <?php echo esc_attr($post_layout == 'list-1-left' ? 'offset-lg-1': ''); ?>">
                                                            <h1 class="heading heading-medium dark-2">
                                                                <p class="paragraph"><?php echo esc_html__('There are no posts to display.', 'slope') ?></p>
                                                            </h1>
                                                        </div>
                                                    <?php endif; // ending - if( $the_query->have_posts() ) ?>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <?php
                                        // display sidebar on the right side
                                        if (
                                            $show_sidebar_archive &&
                                            $archive_sidebar_location == '2' &&
                                            is_active_sidebar('archive-sidebar')
                                        ):
                                    ?>
                                        <!--
                                        right sidebar - start
                                        -->
                                        <div class="col-lg-4 sidebar-column">
                                            <div class="sidebar-column-wrapper">
                                                <ul class="widget widget-container">
                                                    <?php dynamic_sidebar( 'archive-sidebar'); ?>
                                                </ul>
                                            </div>
                                        </div>
                                        <!--
                                        right sidebar - end
                                        -->
                                <?php endif; // ending - right sidebar condition ?>
                            </div>
                        </div>
                    <?php else:  ?>
                        <div class="container">
                            <div class="row">
                                <div class="col-lg-12">
                                <div class="search-error-content">
                                    <?php if (isset($gfxpartner_slope['illustration_404']['url'])): ?>
                                    <div class="illustration">
                                        <img src="<?php echo esc_url($gfxpartner_slope['illustration_404']['url']); ?>"
                                        alt="search-error">
                                    </div>
                                    <?php endif; ?>

                                    <h1 class="heading heading-large dark-1">
                                        <span><?php the_archive_title(); ?></span>
                                    </h1>

                                    <h2 class="heading heading-medium">
                                        <?php echo esc_html__('Sorry, but there are no posts available.', 'slope'); ?>
                                    </h2>

                                    <?php if (has_nav_menu('search')): ?>
                                        <p class="paragraph"><?php echo esc_html__('You can browse through some helpful links below:', 'slope'); ?></p>
                                        <div class="navigation-menu-menu">
                                            <div class="navigation-menu-menu--wrapper">
                                                <?php
                                                    wp_nav_menu(array(
                                                        'theme_location' => 'search',
                                                        'container' => 'ul',
                                                        'link_before' => '<span>',
                                                        'link_after' => '</span>',
                                                        'depth'     => 1,
                                                    ));
                                                ?>
                                            </div>
                                        </div>
                                    <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>
  
<?php get_footer(); ?>