<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


/****************************************
include files
****************************************/
require_once(get_template_directory().'/inc/elementor-widgets/elementor-init.php');
require_once(get_template_directory().'/inc/comments/comment-function.php');
require_once(get_template_directory().'/inc/installation/main.php');
require_once(get_template_directory().'/inc/ajax/project-ajax.php');


/****************************************
Init
****************************************/
if (!function_exists('slope_init')) {
function slope_init() {

  /****************************************
  add theme support
  ****************************************/
  add_theme_support('title-tag');
  add_theme_support('post-thumbnails');
  add_theme_support('widgets'); 
  add_theme_support('automatic-feed-links');

  add_image_size('slope-project-thumbnail-size', 897, 811, true);
  add_image_size('slope-service-thumbnail-size', 499, 499, true);

  add_post_type_support( 'service', 'excerpt' );

  register_nav_menus(array(
    'primary_menu' => esc_html__('Primary menu', 'slope'),
    'error' => esc_html__('404 page menu', 'slope'),
    'search' => esc_html__('Search error menu', 'slope')
  ));

  /****************************************
  set content width
  ****************************************/
  if (!isset($content_width)) $content_width = 900;
}
}
add_action( 'init', 'slope_init' );

/****************************************
custom logo settings
****************************************/
if (!function_exists('slope_custom_logo_setup')){
function slope_custom_logo_setup() {
  $defaults = array(
  'height'      => 75,
  'width'       => 75,
  'flex-height' => true,
  'flex-width'  => true,
  'header-text' => array( 'site-title', 'site-description' ),
 'unlink-homepage-logo' => false, 
  );
  add_theme_support( 'custom-logo', $defaults );
 }
}
 add_action( 'after_setup_theme', 'slope_custom_logo_setup' );


/****************************************
stop contact form 7 from adding p tags
****************************************/
add_filter('wpcf7_autop_or_not', '__return_false');

/****************************************
add html support
****************************************/
if (!function_exists('slope_assets_setup')){
function slope_assets_setup() {

    load_theme_textdomain( 'slope', get_template_directory() . '/inc/languages' );

    add_theme_support('html5', array(
    'search-form',
    'comment-form',
    'comment-list',
    'gallery',
    'caption'));

}
}
add_action( 'after_setup_theme', 'slope_assets_setup' );

/****************************************
enqueue styles and scripts
****************************************/
if (!function_exists('slope_enqueue')){
function slope_enqueue() {
    global $gfxpartner_slope;
  
    wp_enqueue_style('slope-fonts', slope_fonts_url(), array(), false, 'all');
    wp_enqueue_style('swiper', get_template_directory_uri().'/inc/assets/css/swiper-bundle.min.css', array(), '6.4.5', 'all');
    wp_enqueue_style('bootstrap', get_template_directory_uri().'/inc/assets/css/bootstrap.min.css', array(), '4.5.2', 'all');
    wp_enqueue_style('isotope', get_template_directory_uri().'/inc/assets/css/isotope.css', array(), '1.0.0', 'all');
    wp_enqueue_style('bootstrap-select', get_template_directory_uri().'/inc/assets/css/bootstrap-select.min.css', array(), '1.13.14', 'all');
    wp_enqueue_style('overlay-scrollbar', get_template_directory_uri().'/inc/assets/css/OverlayScrollbars.min.css', array(), '1.13.0', 'all');
    wp_enqueue_style('fontawesome', get_template_directory_uri().'/inc/assets/css/all.min.css', array(), '5.15.1', 'all');
    wp_enqueue_style('slope-main-style', get_template_directory_uri().'/style.css', array(), false, 'all');

    wp_enqueue_script('overlay-scrollbar', get_template_directory_uri().'/inc/assets/js/jquery.overlayScrollbars.min.js', array('jquery'), '1.13.0', true);
    wp_enqueue_script('popper', get_template_directory_uri().'/inc/assets/js/popper.min.js', array('jquery'), false, true);
    wp_enqueue_script('masonry', get_template_directory_uri().'/inc/assets/js/masonry.pkgd.min.js', array(), '4.2.2', false);
    wp_enqueue_script('bootstrap', get_template_directory_uri().'/inc/assets/js/bootstrap.min.js', array('jquery'), '4.5.2', true);
    wp_enqueue_script('bootstrap-select', get_template_directory_uri().'/inc/assets/js/bootstrap-select.min.js', array('jquery'), '1.13.14', true);
    wp_enqueue_script('isotope', get_template_directory_uri().'/inc/assets/js/isotope.pkgd.min.js', array('jquery'), '3.0.6', false);
    wp_enqueue_script('slope-color-manager', get_template_directory_uri().'/inc/assets/js/color-manager.js', array('jquery'), '3.0.6', false);
    wp_enqueue_script('gsap', get_template_directory_uri().'/inc/assets/js/gsap.min.js', array(),'3.9.1', true);
    wp_enqueue_script('swiper', get_template_directory_uri().'/inc/assets/js/swiper-bundle.min.js', array(), '6.4.5', false);
    wp_register_script('slope-main-js', get_template_directory_uri().'/inc/assets/js/main.js', array('jquery'), false, true);
    
    $enable_custom_scrollbar = false;

    if (isset($gfxpartner_slope['enable_custom_scrollbar']) && $gfxpartner_slope['enable_custom_scrollbar']) {
      $enable_custom_scrollbar = $gfxpartner_slope['enable_custom_scrollbar'];
    }

    wp_localize_script('slope-main-js', 'js_props', array(
      'enable_custom_scrollbar' => $enable_custom_scrollbar
    ));

    wp_enqueue_script('slope-main-js');

    if ( is_singular() ) wp_enqueue_script( "comment-reply" );
}
}
add_action('wp_enqueue_scripts', 'slope_enqueue');

require_once(get_template_directory().'/inc/custom-styles/styles.php');

/****************************************
elementor support for cpt
****************************************/
if (!function_exists('slope_add_cpt_support')){
function slope_add_cpt_support() {
    
	$cpt_support = get_option( 'elementor_cpt_support' );
	
	if( ! $cpt_support ) {
	    $cpt_support = [ 'page', 'post', 'project', 'service' ];
	    update_option( 'elementor_cpt_support', $cpt_support );
	}
	
	else if( ! in_array( 'project', $cpt_support ) ) {
	    $cpt_support[] = 'project';
	    update_option( 'elementor_cpt_support', $cpt_support );
  }
  
	else if( ! in_array( 'service', $cpt_support ) ) {
    $cpt_support[] = 'service';
    update_option( 'elementor_cpt_support', $cpt_support );
  }

}
}
add_action('after_switch_theme', 'slope_add_cpt_support');

/****************************************
register sidebars
****************************************/
if (!function_exists('slope_register_sidebar')) {
function slope_register_sidebar() {
  register_sidebar(array(
    'name'          => esc_html__('Blog sidebar', 'slope'),
    'id'            => 'blog-sidebar',
  ));
  register_sidebar(array(
    'name'          => esc_html__('Archive sidebar', 'slope'),
    'id'            => 'archive-sidebar',
  ));
  register_sidebar(array(
    'name'          => esc_html__('Search sidebar', 'slope'),
    'id'            => 'search-sidebar',
  ));
}
}
add_action( 'widgets_init', 'slope_register_sidebar' );

/****************************************
Allow SVG
****************************************/
if (!function_exists('slope_check_filetype_and_ext')){
function slope_check_filetype_and_ext($data, $file, $filename, $mimes) {

  global $wp_version;
  if ( $wp_version !== '4.7.1' ) {
     return $data;
  }

  $filetype = wp_check_filetype( $filename, $mimes );

  return [
      'ext'             => $filetype['ext'],
      'type'            => $filetype['type'],
      'proper_filename' => $data['proper_filename']
  ];
}
}
add_filter( 'wp_check_filetype_and_ext', 'slope_check_filetype_and_ext', 10, 4 );

if (!function_exists('slope_cc_mime_types')){
function slope_cc_mime_types( $mimes ){
  $mimes['svg'] = 'image/svg+xml';
  return $mimes;
}
}
add_filter( 'upload_mimes', 'slope_cc_mime_types' );

if (!function_exists('slope_fix_svg')){
function slope_fix_svg() {
  echo '<style type="text/css">
        .attachment-266x266, .thumbnail img {
             width: 100% !important;
             height: auto !important;
        }
        </style>';
}
}
add_action( 'admin_head', 'slope_fix_svg' );

/****************************************
excerpt
****************************************/
if (!function_exists('slope_excerpt_length')){
function slope_excerpt_length( $length ) {
  return 18;
}
}
add_filter( 'excerpt_length', 'slope_excerpt_length');

if (!function_exists('slope_excerpt_more')){
function slope_excerpt_more( $more ) {
	return '...';
}
}
add_filter('excerpt_more', 'slope_excerpt_more');

/****************************************
Lazy load images
****************************************/
if (!function_exists('slope_disable_lazy_load')){
function slope_disable_lazy_load() {
  global $gfxpartner_slope;
  if (!isset($gfxpartner_slope['enable_lazy_loading_images'])) {
    return;
  }
  if (!$gfxpartner_slope['enable_lazy_loading_images']) {
    add_filter( 'wp_lazy_loading_enabled', '__return_false' );
  }
}
}
add_action('init', 'slope_disable_lazy_load');

/****************************************
Remove redux dashboard widget
****************************************/
if (!function_exists('slope_redux_remove_dashboard_widget')) {
function slope_redux_remove_dashboard_widget() {
  remove_meta_box( 'redux_dashboard_widget', 'dashboard', 'side' );
}
}
add_action( 'wp_dashboard_setup', 'slope_redux_remove_dashboard_widget', 100 );

/****************************************
Allowed HTML Tags
****************************************/
if (!function_exists('slope_kses_allowed_html')) {
function slope_kses_allowed_html($tags, $context) {
  switch($context) {
    case 'general': 
      $tags = wp_kses_allowed_html('post');
      return $tags;
    case 'br-allowed':
      $tags = array(
        'br' => array()
      );
      return $tags;
    case 'anchor-allowed':
      $tags = array(
        'a' => array(
          'href' => array(),
          'class' => array(),
          'id' => array()
        )
      );
      return $tags;
    default: 
      return $tags;
  }
}
}
add_filter( 'wp_kses_allowed_html', 'slope_kses_allowed_html', 10, 2);

/****************************************
slope fonts url
****************************************/
if (!function_exists('slope_fonts_url')){
function slope_fonts_url() {
  $fonts_url = '';
  $font     = '';
  $subsets   = 'latin,latin-ext';
  /* translators: If there are characters in your language that are not supported by Spartan, translate this to 'off'. Do not translate into your own language. */
  $font = 'Spartan:500,600,700&display=swap';

  if ( $font ) {
      $fonts_url = add_query_arg( array(
          'family' =>  $font,
          'subset' =>  $subsets,
      ), '//fonts.googleapis.com/css' );
  }
  return esc_url_raw($fonts_url);
}
}

/****************************************
Get categories for a single post
****************************************/
if (!function_exists('slope_get_blog_categories')) {
function slope_get_blog_categories($post_id) {
  $categories = get_the_category($post_id);
  $i = 0;

  ob_start();

  foreach ($categories as $category) {
      if ($i > 2) { break; }
      if ( $category ) {
          if ($i > 0) {
              echo esc_html(', ');
          }
      ?>
          <a href="<?php echo esc_url(get_category_link($category)); ?>">
              <?php echo esc_html($category->cat_name);?>
          </a>
      <?php
      }
      $i++;
  }
  if (empty($categories)) {
      echo esc_html__('Uncategorized', 'slope');
  }
  return ob_get_clean();
}
}