<?php 

    global $gfxpartner_slope; 
    
    // whether to display the preloading animation at the start of the page.
    $preloader_enable = true;
    if ( isset( $gfxpartner_slope['preloader_enable'] ) ) {
        $preloader_enable = $gfxpartner_slope['preloader_enable'];
    }

    // whether the navigation should be displayed or not.
    $nav_cond = false;
    if ( has_nav_menu('primary_menu') || has_custom_logo() ) {
        $nav_cond = true;
    }

    $nav_class = [ 'navigation' ];

    // whether the navigation is sticky or not.
    if ( isset( $gfxpartner_slope['navigation_menu_sticky'] ) && $gfxpartner_slope['navigation_menu_sticky'] ) {
        array_push( $nav_class, 'enabled-sticky' );
    }

    // navigation image
    $show_nav_img = false;

    if ( isset( $gfxpartner_slope['navigation_menu_image']['id'] ) && !empty( $gfxpartner_slope['navigation_menu_image']['id'] ) ) {
        $show_nav_img = true;
    }

    // whether the social icons should be displayed or not.
    $nav_social = false;
    if ( isset( $gfxpartner_slope['social_show_header'] ) && !empty( $gfxpartner_slope['social_show_header'] ) ) {
        $nav_social = true;
    }

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="format-detection" content="telephone=no">
    <?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>

<?php 

    wp_body_open();

    // get the preloader
    if ( $preloader_enable ) {
        get_template_part( '/inc/template/part', 'preloader' );
    }
?>

<?php if ( $nav_cond ): ?>
<div class="navigation-wrapper">
    <div class="placeholder"></div>   
    <nav class="<?php echo esc_attr( implode( ' ', $nav_class ) ); ?>">
        <div class="navigation-bar">
            <div class="logo">
                <?php if ( has_custom_logo() ):
                        the_custom_logo();
                    else: 
                ?>
                    <a href="<?php echo esc_url( home_url() ); ?>" class="default">
                        <h3><?php echo esc_html( get_bloginfo( 'name' ) ); ?></h3>
                    </a>
                <?php endif; ?>
            </div>
            <?php if ( has_nav_menu( 'primary_menu' ) ): ?>
                <div class="hamburger <?php echo esc_html( !has_custom_logo() ? 'default-logo' : '' ); ?>">
                    <a href="#">
                        <div class="bar"></div>
                        <div class="bar"></div>
                        <div class="bar"></div>
                        <div class="bar"></div>
                    </a>
                </div>
            <?php endif; ?>
        </div>
        <?php if ( has_nav_menu('primary_menu') ): ?>
        <div class="navigation-menu">
            <?php if ( $show_nav_img ): ?>
                <div class="navigation-menu-image">
                    <?php echo wp_get_attachment_image( $gfxpartner_slope['navigation_menu_image']['id'], 'full' ); ?>
                </div>
            <?php endif; ?>
            <div class="navigation-menu-menu">
                <div class="navigation-menu-menu--wrapper">
                <?php 
                    wp_nav_menu(array(
                        'theme_location' => 'primary_menu',
                        'container' => 'ul',
                    )); 
                ?>
                </div>
                <?php 
                    if ( $nav_social ) {
                        get_template_part('/inc/template/part', 'social');
                    } 
                ?>
            </div>
        </div>
        <?php endif; ?>
    </nav>
</div>
<?php endif; ?>
