<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/****************************************
comment
****************************************/
if (!function_exists('slope_comment_style')) {
function slope_comment_style($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment;
    extract($args, EXTR_SKIP);
    
    if ( 'div' == $args['style'] ) {
        $tag = 'div';
        $add_below = 'comment';
    } else {
        $tag = 'article';
        $add_below = 'comment';
    }

    $is_pingback = $comment->comment_type == 'pingback';
    $is_traceback = $comment->comment_type == 'trackback';

    ?>
    <<?php echo esc_html($tag) ?> 
        <?php comment_class(array(empty( $args['has_children'] ) ? '' : 'has-reply', 'comment')) ?> 
        id="comment-<?php comment_ID() ?>"
    >
        <div class="parent--comment">

            <?php if (!$is_pingback && !$is_traceback): ?>
                <div class="comment--avatar">
                    <?php
                    // if the commenter has a gravatar, then display it otherwise display a default image
                    if (
                        $comment->user_id || 
                        email_exists($comment->comment_author_email) || 
                        rodio_validate_gravatar($comment->comment_author_email)
                        ): 
                    ?>
                        <?php echo get_avatar( $comment, 64, '', '', '' ); ?>
                    <?php else: ?>
                        <img src="<?php echo get_template_directory_uri().'/inc/assets/images/comment_placeholder.png' ?>" alt="comment-image">
                    <?php endif; ?>
                </div>
            <?php endif; ?>
            
            <div class="comment--content" role="complementary">

                <div class="comment-inner-wrapper">
                    <a href="<?php comment_author_url(); ?>">
                        <h4 class="name"><?php comment_author(); ?></h4>
                    </a>
                    <?php if (!$is_pingback && !$is_traceback): ?>
                        <h5 class="date"><?php comment_date() ?></h5>
                    <?php endif; ?>
                </div>

                <?php if ($comment->comment_approved == '0') : ?>
                    <p class="comment-meta-item paragraph dark"><?php echo esc_html__('Your comment is awaiting moderation.', 'slope') ?></p>
                <?php else: ?>

                    <?php if (($comment->comment_type == 'pingback' || $comment->comment_type == 'trackback') && !$args['short_ping']): ?>
                        <?php comment_text() ?>
                    <?php endif; ?>
                    <?php if ($comment->comment_type != 'pingback' && $comment->comment_type != 'trackback'): ?>
                        <?php comment_text() ?>
                    <?php endif; ?>

                <?php endif; ?>

                <?php if (!$is_pingback && !$is_traceback): ?>
                    <div class="reply-button">
                        <?php comment_reply_link(array_merge( $args, array('add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
                    </div>
                <?php endif; ?>
            </div>
        </<?php echo esc_html($tag) ?>>
    <?php }
}
/****************************************
comment fields
****************************************/
if ( !function_exists( 'rodio_default_comment_fields' ) ) {
function rodio_default_comment_fields( $fields ) {
    // author field
    $fields['author'] = '
    <div class="comment-form">
        <div class="comment-form--inner row">
            <div class="col-lg-6">
                <div class="field-group">
                    <input required type="text" id="author" name="author" placeholder="'.__('Name *', 'slope').'" class="input-field">';

    // email field
    $fields['email'] = '
                    <input required type="text" id="email" name="email" placeholder="'.__('Email *', 'slope').'" class="input-field">';

    // url field
    $fields['url'] = '
                    <input type="text" placeholder="'.__('Website', 'slope').'" class="input-field">
                </div>
            </div>';

    // comment content field
    $fields['comment_field'] ='
            <div class="col-lg-6">
                <div class="textarea-group">
                    <textarea required placeholder="'.__('Your reply *', 'slope').'" id="comment" name="comment" class="input-field"></textarea>
                </div>
            </div>';
    
    // cookies field
    $fields['cookies'] = '
            <div class="col">
                <div class="cookies-consent"> 
                    <label for="wp-comment-cookies-consent" class="paragraph">'
                        .__('Save my name, email, and website in this browser for the next time I comment.', 'slope').'
                        <input id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" type="checkbox" value="yes">
                        <span class="checkmark"></span>
                    </label>
                </div>
            </div>
        </div>
    </div>';
   
    return $fields;
  }
}
add_action('comment_form_default_fields', 'rodio_default_comment_fields');

if ( !function_exists( 'rodio_comment_fields' ) ) {
    // move the cookies checkbox to the end of fields
    function rodio_comment_fields($fields) {
        $cookie_field = $fields['cookies'];
        unset($fields['cookies']);
        $fields['cookies'] = $cookie_field;
        return $fields;
    }
}
add_action('comment_form_fields', 'rodio_comment_fields', 99, 1);

if ( !function_exists( 'rodio_validate_gravatar' ) ) {
    function rodio_validate_gravatar($email) {
        // From http://codex.wordpress.org/Using_Gravatars
        // Craft a potential url and test its headers
        $hash = md5($email);
        $uri = 'http://www.gravatar.com/avatar/' . $hash . '?d=404';
        $headers = @get_headers($uri);
        if (empty($headers)) {
            $has_valid_avatar = FALSE;
            return $has_valid_avatar;
        }
        if (!preg_match("|200|", $headers[0])) {
            $has_valid_avatar = FALSE;
        } else {
            $has_valid_avatar = TRUE;
        }
        return $has_valid_avatar;
    }
}