<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly

function slope_render_script($id, $options, $testimonial = false) {
    global $gfxpartner_slope;
?>
    <script>
        (function($) {
            "use strict";
            $(window).on('load', function() {
                let options<?php echo esc_attr($id);?> = <?php echo wp_json_encode( $options ); ?>;
                
                if (<?php echo json_encode($testimonial); ?>) {
                    options<?php echo esc_attr($id);?>['runCallbacksOnInit'] = true;
                    options<?php echo esc_attr($id);?>['init'] = false;
                }
                let swiper<?php echo esc_attr($id);?> = new Swiper('.slider-<?php echo esc_attr($id);?>', options<?php echo esc_attr($id);?>);
                if (<?php echo json_encode($testimonial); ?>) {
                    swiper<?php echo esc_attr($id);?>.on('init', function(){ 
                        let offer = $(".slider--nav-numbers-<?php echo esc_attr($id); ?>");
                        if (swiper<?php echo esc_attr($id);?>.slides.length < 10) {
                            offer.html('0' + (swiper<?php echo esc_attr($id);?>.activeIndex +  1) + ' / ' + '0' + swiper<?php echo esc_attr($id);?>.slides.length); 
                        } else {
                            offer.html((swiper<?php echo esc_attr($id);?>.activeIndex +  1) + ' / ' + swiper<?php echo esc_attr($id);?>.slides.length); 
                        }
                    });
                    swiper<?php echo esc_attr($id);?>.on('transitionEnd', function(){ 
                        let offer = $(".slider--nav-numbers-<?php echo esc_attr($id); ?>");
                        if (swiper<?php echo esc_attr($id);?>.slides.length < 10) {
                            offer.html('0' + (swiper<?php echo esc_attr($id);?>.activeIndex +  1) + ' / ' + '0' + swiper<?php echo esc_attr($id);?>.slides.length); 
                        } else {
                            offer.html((swiper<?php echo esc_attr($id);?>.activeIndex +  1) + ' / ' + swiper<?php echo esc_attr($id);?>.slides.length); 
                        }
                    });
                    swiper<?php echo esc_attr($id);?>.init();
                }
                
            });
        })(jQuery);
    </script>
<?php
}

function slope_render_isotope_script($id) {
    ?>
    <script>
        (function($) {
            "use strict";
            $(window).on('load', () => {
                let $container_<?php echo esc_attr($id); ?> = $('.blog-list-container-<?php echo esc_attr($id); ?>'); //The ID for the list with all the blog posts
                $container_<?php echo esc_attr($id); ?>.isotope({ //Isotope options, 'item' matches the class in the PHP
                    itemSelector : '.blog-list-item-<?php echo esc_attr($id); ?>', 
                    layoutMode : 'fitRows'
                }).css('overflow','hidden');

                //Add the class selected to the item that is clicked, and remove from the others
                let $optionSets_<?php echo esc_attr($id); ?> = $('.filter-<?php echo esc_attr($id); ?>'),
                $optionLinks_<?php echo esc_attr($id); ?> = $optionSets_<?php echo esc_attr($id); ?>.find('a');
                
                $optionLinks_<?php echo esc_attr($id); ?>.click(function(){
                    let $this = $(this);

                    // don't proceed if already selected
                    if ( $this.hasClass('selected') ) {
                        return false;
                    }

                    let $optionSet_<?php echo esc_attr($id); ?> = $this.parents('.filter-<?php echo esc_attr($id); ?>');
                    $optionSets_<?php echo esc_attr($id); ?>.find('.selected').removeClass('selected');
                    $this.addClass('selected');

                    //When an item is clicked, sort the items.
                    let selector_<?php echo esc_attr($id); ?> = $(this).attr('data-filter');
                    $container_<?php echo esc_attr($id); ?>.isotope({ filter: selector_<?php echo esc_attr($id); ?> });

                    return false;
                });

                let selectBox_<?php echo esc_attr($id); ?> = $optionSets_<?php echo esc_attr($id); ?>.find('select');

                $(selectBox_<?php echo esc_attr($id); ?>).on('change', (e) => {            
                    $container_<?php echo esc_attr($id); ?>.isotope({ filter: e.target.value });
                });
            });
        })(jQuery);
        
    </script>
    <?php
}

function slope_project_load_script($id, $project_count) {
    $nonce = wp_create_nonce( 'projects-load-more' );
    ?>
    <script>
        (function($){
            "use strict";
            $(window).on('load', () => {
                // the number of posts to skip
                let offset = <?php echo esc_attr( $project_count ); ?>;

                let button_container = '.load-more-<?php echo esc_attr( $id ); ?>';

                $(`${button_container} .button`).on('click', () => {

                    let container = '.project-list-<?php echo esc_attr($id); ?>';

                    let ajax_url = '<?php echo esc_url(home_url()); ?>/wp-admin/admin-ajax.php';

                    let data = {
                        'action': 'slope_load_more_projects',
                        'offset': offset,
                        'security': '<?php echo sanitize_key($nonce); ?>',
                    };
        
                    $.post(ajax_url, data, (response) => {
                        if (response === '') {
                            $(button_container).hide();
                            return;
                        }

                        $(container).append(response).css('opacity', '1');

                        offset += 4;

                        let final_cond = $('.project-list-<?php echo esc_attr($id); ?> .project-list-single--wrapper').length == $('.project-list-<?php echo esc_attr($id); ?>').attr('data-max');

                        if (final_cond) {
                            $(button_container).hide();
                        }
                
                    });
                });
            });
        })(jQuery);
    </script>
    <?php
}

function slope_svg_script() {
    ?>
    <script>
        (function($){
            "use strict";
            $('img.svg').each(function(){
                let $img = $(this);
                let imgID = $img.attr('id');
                let imgClass = $img.attr('class');
                let imgURL = $img.attr('src');

                $.get(imgURL, function(data) {
                    // Get the SVG tag, ignore the rest
                    let $svg = $(data).find('svg');

                    // Add replaced image's ID to the new SVG
                    if(typeof imgID !== 'undefined') {
                        $svg = $svg.attr('id', imgID);
                    }
                    // Add replaced image's classes to the new SVG
                    if(typeof imgClass !== 'undefined') {
                        $svg = $svg.attr('class', imgClass+' replaced-svg');
                    }

                    // Remove any invalid XML tags as per http://validator.w3.org
                    $svg = $svg.removeAttr('xmlns:a');

                    // Replace image with new SVG
                    $img.replaceWith($svg);

                }, 'xml');

            });
        })(jQuery);
      </script>
    <?php
}

function slope_service_noimage_anim($settings) {
    $ser_no_img_text_color = '#000000';

    if (!empty($settings['ser_no_img_text_color'])) {
        $ser_no_img_text_color = $settings['ser_no_img_text_color'];
    }

    $ser_no_img_text_color_hover = '#ffffff';

    if (!empty($settings['ser_no_img_text_color_hover'])) {
        $ser_no_img_text_color_hover = $settings['ser_no_img_text_color_hover'];
    }

    $ser_no_img_bg_color= '#ffffff';

    if (!empty($settings['ser_no_img_bg_color'])) {
        $ser_no_img_bg_color = $settings['ser_no_img_bg_color'];
    }

    $ser_no_img_border_color = 'var(--slope-main-color)';

    if (!empty($settings['ser_no_img_border_color'])) {
        $ser_no_img_border_color = $settings['ser_no_img_border_color'];
    }

    $ser_no_img_bg_color_hover = '--slope-main-color';

    if (!empty($settings['ser_no_img_bg_color_hover'])) {
        $ser_no_img_bg_color_hover = $settings['ser_no_img_bg_color_hover'];
    }

    $ser_no_img_border_color_hover = 'var(--slope-main-color)';

    if (!empty($settings['ser_no_img_border_color_hover'])) {
        $ser_no_img_border_color_hover = $settings['ser_no_img_border_color_hover'];
    }
    

    ?>
        <script>
            (function($){
                "use strict";
                
                $(window).on('load', () => {
                    $('.service-withoutimage .service--box-icon').on('mouseenter', service_no_image_anim);

                    let main_color = '<?php echo esc_html($ser_no_img_bg_color); ?>';
                    let main_color_hover = '<?php echo esc_html($ser_no_img_bg_color_hover); ?>';

                    if ( main_color.includes('--') ) {
                        main_color = getComputedStyle(document.body).getPropertyValue(main_color).trim();
                    }

                    if ( main_color_hover.includes('--') ) {
                        main_color_hover = getComputedStyle(document.body).getPropertyValue(main_color_hover).trim();
                    }

                    console.log( hexa_to_rgba(main_color_hover) )

                    function service_no_image_anim(e) {
                        let objectClass = this.className.replace('service--box-icon ', '.');
                        let icon = $(`${objectClass} > a > .icon`);
                        let text = $(`${objectClass} > a > .text`);
                        const tl = new gsap.timeline({ defaults: { duration: .4, ease: "Sine.easeout" } });

                        let top_value = '30%';
                        if ( $(window).width() < 768 ) {
                            top_value = '22.5%';
                        }

                        tl
                            .fromTo(
                                icon, 
                                { 
                                    right: '3.5rem', 
                                    x: 0, 
                                    top: '3.5rem' 
                                }, 
                                { 
                                    right: '50%', 
                                    x: '50%', 
                                    top: top_value
                                }
                            );
                        
                        if ($(`${objectClass} > a > .icon i`).length > 0) {
                            tl
                                .fromTo(
                                    `${objectClass} > a > .icon i`,
                                    { 
                                        color: '<?php echo esc_html($ser_no_img_text_color); ?>'
                                    }, 
                                    { 
                                        color: '<?php echo esc_html($ser_no_img_text_color_hover); ?>', 
                                        delay: -.4
                                    }
                                );
                        }

                        if ($(`${objectClass} > a > .icon svg`).length > 0) {
                            tl.
                                fromTo(
                                    `${objectClass} > a > .icon svg path`, 
                                    { 
                                        fill: '<?php echo esc_html($ser_no_img_text_color); ?>' 
                                    }, 
                                    { 
                                        fill: '<?php echo esc_html($ser_no_img_text_color_hover); ?>', 
                                        delay: -.4 
                                    }
                                );

                        }
                        
                        tl
                            .fromTo(
                                `${objectClass} > a > .text h4`, 
                                { 
                                    color: '<?php echo esc_html($ser_no_img_text_color); ?>' 
                                }, 
                                { 
                                    color: '<?php echo esc_html($ser_no_img_text_color_hover); ?>', 
                                    delay: -.4 
                                }
                            )
                            .fromTo(
                                text, 
                                { 
                                    left: '3.5rem', 
                                    x: 0, 
                                    bottom: '1.9rem' 
                                }, 
                                { 
                                    left: '50%', 
                                    x: '-50%', 
                                    bottom: '27%', 
                                    delay: -.4 
                                }
                            )
                            .fromTo(
                                `${objectClass}`,
                                { 
                                    backgroundColor: hexa_to_rgba(main_color),
                                    borderColor: '<?php echo esc_html($ser_no_img_border_color); ?>',
                                    delay: -.4 
                                },
                                { 
                                    backgroundColor: hexa_to_rgba(main_color_hover),
                                    borderColor: '<?php echo esc_html($ser_no_img_border_color_hover); ?>',  
                                    delay: -.4 
                                }
                            );

                        $(this).on('mouseleave', () => {
                            tl.reverse();
                        })
                    }
                });
            })(jQuery);
        </script>
    <?php
}

function slope_service_image_anim($settings) {

    $ser_img_icon_bg_color = '--slope-main-color';

    if (!empty($settings['ser_img_icon_bg_color'])) {
        $ser_img_icon_bg_color = $settings['ser_img_icon_bg_color'];
    }

    $ser_img_icon_bg_color_hover = '--slope-main-color-50';

    if (!empty($settings['ser_img_icon_bg_color_hover'])) {
        $ser_img_icon_bg_color_hover = $settings['ser_img_icon_bg_color_hover'];
    }

    $ser_img_text_color = 'var(--slope-foreground)';

    if (!empty($settings['ser_img_text_color'])) {
        $ser_img_text_color = $settings['ser_img_text_color'];
    }

    $ser_img_text_color_hover = '#ffffff';

    if (!empty($settings['ser_img_text_color_hover'])) {
        $ser_img_text_color_hover = $settings['ser_img_text_color_hover'];
    }

    ?>
        <script>
            (function($){
                "use strict";

                $(window).on('load', () => {
                    let main_color = '<?php echo esc_html( $ser_img_icon_bg_color ); ?>';
                    let hover_color = '<?php echo esc_html( $ser_img_icon_bg_color_hover ); ?>';

                    if ( main_color.includes('--') ) {
                        main_color = getComputedStyle(document.body).getPropertyValue(main_color).trim();
                    }

                    if ( hover_color.includes('--') ) {
                        hover_color = getComputedStyle(document.body).getPropertyValue(hover_color).trim();
                    }  

                    /********************
                    service box animation
                    ********************/
                    $('.service-image .service--box').on('mouseenter', service_image_anim);

                    $(window).on('resize', (e) => {
                        if ($(window).width() <= 900) {
                            $('.service--box--image .icon').css({
                                'bottom': 0,
                                'transform': 'translate(0,0)'
                            })
                        } else {
                            $('.service--box--image .icon').css({
                                'bottom': '50%',
                                'transform': 'translate(0,-50%)'
                            })
                        }
                    });

                    function service_image_anim(e) {
                        if ($(window).width() < 992) {   
                            return;
                        }
                        let selector = $(e.target).parents('.service--box')[0];

                        let selectorClass = selector.className.replace('service--box ', '');
                        let iconImage = `.${selectorClass} > .service--box--image`;
                        let iconBox = `.${selectorClass} > .service--box--image .icon`;
                        let icon = `.${selectorClass} > .service--box--image .icon > i`;
                        let iconSVG = `.${selectorClass} > .service--box--image .icon > svg`;
                        let iconSVGPath = `.${selectorClass} > .service--box--image .icon svg path`;

                        let selectorPosition = $(selector).index() + 1;

                        const tl = new gsap.timeline({ defaults: { duration: .5, ease: "power4.out" } });

                        tl
                            .fromTo(
                                iconBox, 
                                { 
                                    width: '13.5rem', 
                                    height: '13.5rem', 
                                    opacity: 1, 
                                    backgroundColor: hexa_to_rgba(main_color)
                                },
                                { 
                                    width: '100%', 
                                    height: '100%', 
                                    opacity: 1,  
                                    backgroundColor: hexa_to_rgba(hover_color)
                                }
                            );

        
                        
                        if ($(icon).length > 0) {
                            tl            
                                .fromTo(
                                    icon, 
                                    { 
                                        fontSize: '7rem', 
                                        color: '<?php echo esc_html( $ser_img_text_color ); ?>' 
                                    }, 
                                    { 
                                        fontSize: '10rem', 
                                        delay: -.5, color: '<?php echo esc_html( $ser_img_text_color_hover ); ?>' 
                                    }
                                );
                        }
                        if ($(iconSVG).length > 0) {
                            tl
                                .fromTo(
                                    iconSVGPath, 
                                    { 
                                        fill: '<?php echo esc_html( $ser_img_text_color ); ?>', 
                                        delay: -.5 
                                    }, 
                                    { 
                                        fill: '<?php echo esc_html( $ser_img_text_color_hover ); ?>', 
                                        delay: -.5 
                                    }
                                )
                                .fromTo(
                                    iconSVG, 
                                    { 
                                        x: '-50%', 
                                        y: '-50%', 
                                        scale: 1, 
                                        delay: -.5 
                                    }, 
                                    { 
                                        x: '-50%', 
                                        y: '-50%', 
                                        scale: 1.5, 
                                        delay: -.5 
                                    }
                                );
                        }

                        $(selector).on('mouseleave', () => {
                            tl.reverse();
                        })
                    }
                })
            })(jQuery);
    </script>
    <?php
}

function slope_widget_link_pages($query = '', $prev_text = '', $next_text = '') {

	if($query == '') {
		global $wp_query;
		$query = $wp_query;
	}

	$args =  array(
		'base'         => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
		'total'        => $query->max_num_pages,
		'current'      => max( 1, get_query_var( 'paged' ) ),
		'format'       => '?paged=%#%',
		'show_all'     => false,
		'type'      => 'list',
		'end_size'     => 2,
		'mid_size'     => 1,
		'prev_next'    => false,
		'add_args'     => false,
		'add_fragment' => '',
	) ;
	echo '<div class="pagination-container">';
	echo paginate_links( $args );
	echo '</div>';
}