<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Heading extends \Elementor\Widget_Base{

  public function get_name(){
    return 'heading_slope';
  }

  public function get_title(){
    return __( 'Heading', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-text-height';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls() {

    // heading content - start

    $this->start_controls_section(
      'heading_content',
      [
        'label' => __('Content', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $this->add_control(
      'heading_control',
      [
        'label' => __('Heading', 'slope'),
        'type' => \Elementor\Controls_Manager::WYSIWYG,
        'default' => ''
      ]
    );

    $this->end_controls_section();

    // heading content - end

    // heading preset - start

    $this->start_controls_section(
      'heading_preset_section',
      [
        'label' => __('Preset', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_control(
      'heading_preset',
      [
        'label' => __( 'Heading preset', 'slope' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'large',
        'options' => [
          'heading-very-large'  => __( 'Very large heading', 'slope' ),
          'heading-large' => __( 'large heading', 'slope' ),
          'heading-medium' => __( 'medium heading', 'slope' ),
          'heading-small' => __( 'small heading', 'slope' ),
        ],
      ]
    );

    $this->add_control(
      'heading_color_preset',
      [
          'label' => __( 'Heading color preset', 'slope' ),
          'type' => \Elementor\Controls_Manager::SELECT,
          'default' => 'dark-1',
          'options' => [
              'dark-1'  => __( 'Dark-1', 'slope' ),
              'dark-2'  => __( 'Dark-2', 'slope' ),
              'light-1' => __( 'Light 1', 'slope' ),
              'light-2' => __( 'Light 2', 'slope' ),
          ],
      ]
    );

    $this->end_controls_section();

    // heading preset - end

    // heading style - start

    $this->start_controls_section(
      'heading_style',
      [
        'label' => __('Style', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
  
    $this->add_responsive_control('heading_align',
      [
          'label'         => __( 'Alignment', 'slope' ),
          'type'          => \Elementor\Controls_Manager::CHOOSE,
          'options'       => [
              'left'      => [
                  'title'=> __( 'Left', 'slope' ),
                  'icon' => 'fa fa-align-left',
              ],
              'center'    => [
                  'title'=> __( 'Center', 'slope' ),
                  'icon' => 'fa fa-align-center',
              ],
              'right'     => [
                  'title'=> __( 'Right', 'slope' ),
                  'icon' => 'fa fa-align-right',
              ],
          ],
          'default'       => 'left',
          'selectors'     => [
              '{{WRAPPER}} .heading' => 'text-align: {{VALUE}};',
          ],
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'heading_type',
          'label' => __('Heading', 'slope'),
          'selector' => '{{WRAPPER}} .heading > *',
      ]
    );

    $this->add_control(
      'heading_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .heading > *' => 'color : {{VALUE}}'
        ]
      ]
    );
  
    $this->end_controls_section();

    // heading style - end

    // heading quote - start

    $this->start_controls_section(
        'heading_quote',
        [
          'label' => __('Quote', 'slope'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_control(
      'heading_quote_display',
      [
        'label' => __( 'Display quote', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'Yes', 'slope' ),
        'label_off' => __( 'No', 'slope' ),
        'return_value' => 'quote',
        'default' => '',
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'heading_quote_type',
          'label' => __('Quote Format', 'slope'),
          'selector' => '{{WRAPPER}} .heading.quote > *:first-child::before, {{WRAPPER}} .heading.quote > *:last-child::after',
      ]
    );

    $this->add_control(
      'heading_quote_color',
      [
        'label' => __('Quote', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .heading.quote > *:first-child::before' => 'color : {{VALUE}}',
          '{{WRAPPER}} .heading.quote > *:last-child::after' => 'color : {{VALUE}}',
        ]
        
      ]
    );

    $this->end_controls_section();

    // heading quote - end
  
  }
  

  protected function render() {
    $settings = $this->get_settings_for_display();

    $class_list = array(
      'heading', 
      $settings['heading_preset'], 
      $settings['heading_color_preset'],
      $settings['heading_quote_display']
    );

  ?>
    <div class="<?php echo esc_attr( implode( ' ', $class_list ) ); ?>">
      <?php echo wp_kses($settings['heading_control'], 'general'); ?>
    </div>
    <?php
  }
}
