<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Paragraph extends \Elementor\Widget_Base{

  public function get_name(){
    return 'paragraph_slope';
  }

  public function get_title(){
    return __( 'Paragraph', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-paragraph';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // content - start

    $this->start_controls_section(
      'paragraph_content',
      [
        'label' => __('Content', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $this->add_control(
      'paragraph_control',
      [
        'label' => __('Paragraph', 'slope'),
        'type' => \Elementor\Controls_Manager::WYSIWYG,
        'default' => ''
      ]
    );

    $this->end_controls_section();

    // content - end

    // style - start

    $this->start_controls_section(
        'paragraph_style',
        [
          'label' => __('Style', 'slope'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_control(
      'paragraph_color_preset',
      [
          'label' => __( 'Color preset', 'slope' ),
          'type' => \Elementor\Controls_Manager::SELECT,
          'default' => 'dark-1',
          'options' => [
              'dark-1'  => __( 'Dark-1', 'slope' ),
              'dark-2'  => __( 'Dark-2', 'slope' ),
              'light-1' => __( 'Light 1', 'slope' ),
              'light-2' => __( 'Light 2', 'slope' ),
          ],
      ]
    );

    $this->add_responsive_control('paragraph_align',
      [
          'label'         => __( 'Alignment', 'slope' ),
          'type'          => \Elementor\Controls_Manager::CHOOSE,
          'options'       => [
              'left'      => [
                  'title'=> __( 'Left', 'slope' ),
                  'icon' => 'fa fa-align-left',
              ],
              'center'    => [
                  'title'=> __( 'Center', 'slope' ),
                  'icon' => 'fa fa-align-center',
              ],
              'right'     => [
                  'title'=> __( 'Right', 'slope' ),
                  'icon' => 'fa fa-align-right',
              ],
          ],
          'default'       => 'left',
          'selectors'     => [
              '{{WRAPPER}} .paragraph' => 'text-align: {{VALUE}};',
          ],
      ]
    );

    $this->add_group_control(
        \Elementor\Group_Control_Typography::get_type(),
        [
            'name' => 'paragraph_type',
            'label' => __('Typography', 'slope'),
            'selector' => '{{WRAPPER}} .paragraph > *',
        ]
    );

    $this->add_control(
      'paragraph_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .paragraph > *' => 'color : {{VALUE}}'
        ]
        
      ]
    );

    $this->end_controls_section();

    // style - end

    // link style - start

    $this->start_controls_section(
      'paragraph_link_style',
      [
        'label' => __('Link', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->start_controls_tabs( 'paragraph_link_tabs' );
    
    $this->start_controls_tab(
        'paragraph_link_normal',
        [
            'label' => __( 'Normal', 'slope' ),
        ]
    );

    $this->add_control(
        'paragraph_link_color',
        [
          'label' => __('Link color', 'slope'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .paragraph a' => 'color : {{VALUE}}',
            '{{WRAPPER}} .paragraph a *' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $this->end_controls_tab();

    $this->start_controls_tab(
        'paragraph_link_normalhover',
        [
            'label' => __( 'Hover', 'slope' ),
        ]
    );

    $this->add_control(
        'paragraph_link_normal_hover',
        [
          'label' => __('Link color', 'slope'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .paragraph a:hover' => 'color : {{VALUE}}',
            '{{WRAPPER}} .paragraph a:hover *' => 'color : {{VALUE}}',
          ]
          
        ]
    );

    $this->end_controls_tab();

    $this->end_controls_tabs();
  
    $this->end_controls_section();

    // link style - end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
    
    ?>
        <div class="paragraph <?php echo esc_attr( $settings['paragraph_color_preset'] ); ?>">
          <?php echo wp_kses($settings['paragraph_control'], 'general'); ?>
        </div>
    <?php
  }
}
