<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Tabs extends \Elementor\Widget_Base{

  public function get_name(){
    return 'textList_tabs';
  }

  public function get_title(){
    return __( 'Tabs', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-list';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // heading - start

    $this->start_controls_section(
      'tabs_heading_content',
      [
        'label' => __('Heading', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $this->add_control(
      'tabs_heading',
      [
          'label' => __('Heading', 'slope'),
          'label_block' => true,
          'type' => \Elementor\Controls_Manager::TEXT,
          'default' => ''
      ]
    );

    $this->end_controls_section();

    // heading - end

    // tabs - start

    $this->start_controls_section(
      'tabs_content',
      [
        'label' => __('Tabs', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
        'tab_item',
        [
            'label' => __('Text', 'slope'),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXT,
            'default' => ''
        ]
    );

    $repeater->add_control(
        'tab_content',
        [
            'label' => __( 'Content', 'slope' ),
            'type' => \Elementor\Controls_Manager::WYSIWYG,
        ]
    );


    $this->add_control(
        'tab_item_repeater',
        [
          'label' => __( 'Tabs', 'slope' ),
          'type' => \Elementor\Controls_Manager::REPEATER,
          'fields' => $repeater->get_controls(),
          'default' => [
            [
              'tab_item' => '',
              'tab_content' => ''
            ],
          ],
          'title_field' => __ ( 'Tab','slope' ),
        ]
    );

    $this->end_controls_section();

    // tabs - end

    // heading style - start

    $this->start_controls_section(
      'tabs_heading_style_section',
      [
        'label' => __('Heading', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_control(
      'tab_heading_preset',
      [
        'label' => __( 'Size preset', 'slope' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'large',
        'options' => [
          'heading-very-large'  => __( 'Very large heading', 'slope' ),
          'heading-large' => __( 'large heading', 'slope' ),
          'heading-medium' => __( 'medium heading', 'slope' ),
          'heading-small' => __( 'small heading', 'slope' ),
        ],
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'tab_heading_typography',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .tabs .tabs-list h4',
      ]
    );

    $this->add_control(
      'heading_color_preset',
      [
          'label' => __( 'Color preset', 'slope' ),
          'type' => \Elementor\Controls_Manager::SELECT,
          'default' => 'dark-1',
          'options' => [
              'dark-1'  => __( 'Dark-1', 'slope' ),
              'dark-2'  => __( 'Dark-2', 'slope' ),
              'light-1' => __( 'Light 1', 'slope' ),
              'light-2' => __( 'Light 2', 'slope' ),
          ],
      ]
    );

    $this->add_control(
      'tab_heading_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabs .tabs-list h4' => 'color : {{VALUE}}'
        ]
        
      ]
    );
    
    $this->end_controls_section();

    // heading style - end

    // List style - start

    $this->start_controls_section(
      'tabs_list_style_section',
      [
        'label' => __('List', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_control(
      'list_size_preset',
      [
        'label' => __( 'Size preset', 'slope' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'large',
        'options' => [
          'text-list-large' => __( 'Large', 'slope' ),
          'text-list-medium' => __( 'Medium', 'slope' ),
        ],
      ]
    );

    $this->add_control(
      'list_color_preset',
      [
          'label' => __( 'Color preset', 'slope' ),
          'type' => \Elementor\Controls_Manager::SELECT,
          'default' => 'dark-1',
          'options' => [
              'dark-1'  => __( 'Dark-1', 'slope' ),
              'dark-2'  => __( 'Dark-2', 'slope' ),
              'light-1' => __( 'Light 1', 'slope' ),
              'light-2' => __( 'Light 2', 'slope' ),
          ],
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'tab_item_style',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .text-list li, {{WRAPPER}} .text-list a',
      ]
    );

    $this->add_control(
      'tab_list_item_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .text-list li' => 'color : {{VALUE}}',
          '{{WRAPPER}} .text-list a' => 'color : {{VALUE}}'
        ]
        
      ]
    );

    $this->add_control(
      'list_item_active_bg',
      [
        'label' => __('Hover color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .text-list a::before' => 'background-color : {{VALUE}}',
          '{{WRAPPER}} .nav-pills .nav-link.active::before,{{WRAPPER}} .nav-pills .show>.nav-link::before' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );

    $this->end_controls_section();

    // List style - end

    // Tabs style - start

    $this->start_controls_section(
      'tabs_tab_style_section',
      [
        'label' => __('Tab content', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_control(
      'tab_content_preset',
      [
          'label' => __( 'Color preset', 'slope' ),
          'type' => \Elementor\Controls_Manager::SELECT,
          'default' => 'dark-1',
          'options' => [
              'dark-1'  => __( 'Dark-1', 'slope' ),
              'dark-2'  => __( 'Dark-2', 'slope' ),
              'light-1' => __( 'Light 1', 'slope' ),
              'light-2' => __( 'Light 2', 'slope' ),
          ],
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'tab_content_typography',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .tabs-content .tab-single .paragraph',
      ]
    );

    $this->add_control(
      'tab_content_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabs-content .tab-single .paragraph' => 'color : {{VALUE}}'
        ]
        
      ]
    );

    $this->end_controls_section();

    // Tabs style - end

  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();
    ?>

    <div class="tabs">

    <div class="text-list tabs-list <?php echo esc_attr( $settings['list_size_preset'] ); ?>">
        <h4 class="heading tab-heading <?php echo esc_attr( $settings['tab_heading_preset'].' '.$settings['heading_color_preset'] ); ?>">
          <?php echo esc_html($settings['tabs_heading']); ?>
        </h4>

        <div class="nav-pills-wrapper">
          <ul class="nav nav-pills <?php echo esc_attr( $settings['list_color_preset'] ); ?>" role="tablist">
              <?php
                $incre_id = 1; 
                foreach ($settings['tab_item_repeater'] as $item):
                  $c_id = $id.strval($incre_id);
                  $active = $incre_id == 1 ? 'show active': '';
              ?>
                <li class="nav-item">
                    <a 
                    class="nav-link <?php echo esc_attr( $active ); ?>" 
                    id="slope-tabs-id-<?php echo esc_attr( $c_id ); ?>-tab" 
                    data-toggle="pill" 
                    href="#slope-tabs-id-<?php echo esc_attr( $c_id ); ?>" 
                    role="tab" 
                    aria-controls="slope-tabs-id-<?php echo esc_attr( $c_id ); ?>" 
                    aria-selected="true">
                    <span>
                      <?php echo esc_html($item['tab_item']); ?>
                    </span>
                    </a>
                </li>
              <?php $incre_id++; endforeach; ?>
          </ul>
        </div>
    </div>

    <div class="tabs-content tab-content">
            <?php 
              $incre_id = 1; 
              foreach ($settings['tab_item_repeater'] as $item):
                $c_id = $id.strval($incre_id);
                $active = $incre_id == 1 ? 'show active': '';
            ?>
              <div
                class="tab-single slope-tabs-<?php echo esc_attr( $c_id.' '.$active ); ?> tab-pane fade" 
			          id="slope-tabs-id-<?php echo esc_attr( $c_id ); ?>"
			          role="tabpanel"
			          aria-labelledby="slope-tabs-id-<?php echo esc_attr( $c_id ); ?>-tab"
              >
                <h4 class="heading <?php echo esc_attr( $settings['tab_heading_preset'].' '.$settings['heading_color_preset'] ); ?>">
                    <?php echo esc_html($item['tab_item']); ?>
                </h4>

                <div class="paragraph <?php echo esc_attr( $settings['tab_content_preset'] ); ?>">
                    <?php echo wp_kses($item['tab_content'], 'general'); ?>
                </div>
            </div>
            <?php $incre_id++; endforeach; ?>
    </div>

    </div>
    <?php
  }
}