<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Team extends \Elementor\Widget_Base{

  public function get_name(){
    return 'team_slope';
  }

  public function get_title(){
    return __( 'Team', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-users';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // content - start

    $this->start_controls_section(
      'team_content',
      [
        'label' => __('Content', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $this->add_control(
      'team_image',
      [
          'label' => __( 'Choose Image', 'slope' ),
          'type' => \Elementor\Controls_Manager::MEDIA,
          'default' => [
              'url' => \Elementor\Utils::get_placeholder_image_src(),
          ],
      ]
    );

    $this->add_control(
      'team_name',
      [
      'label' => __('Name', 'slope'),
      'type' => \Elementor\Controls_Manager::TEXT,
      'default' => ''
      ]
    );

    $this->add_control(
      'team_designation',
      [
      'label' => __('Designation', 'slope'),
      'type' => \Elementor\Controls_Manager::TEXT,
      'default' => ''
      ]
    );

    $this->end_controls_section();

    // content - end

    // social icons - start

    $this->start_controls_section(
      'team_content_social',
      [
        'label' => __('Social icons', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
			'team_social_icon',
			[
				'label' => __( 'Icon', 'slope' ),
				'type' => \Elementor\Controls_Manager::ICONS,
			]
		);

    $repeater->add_control(
      'team_social_link',
      [
          'label' => __( 'Link', 'slope' ),
          'type' => \Elementor\Controls_Manager::URL,
          'placeholder' => __( 'https://your-link.com', 'slope' ),
          'show_external' => true,
          'default' => [
              'url' => '',
              'is_external' => true,
              'nofollow' => true,
          ],
      ]
    );

    $this->add_control(
      'team_social_repeater',
      [
        'label' => __( 'Social icons', 'slope' ),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'team_social_icon' => '',
            'team_social_link' => ''
          ],
        ],
        'title_field' => __ ( 'Social icon','slope' ),
      ]
    );

    $this->end_controls_section();

    // social icons - start

    // style - start

    $this->start_controls_section(
        'team_style',
        [
          'label' => __('Style', 'slope'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_group_control(
        \Elementor\Group_Control_Image_Size::get_type(),
        [
            'name' => 'team_image_prop', // // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_prop_size` and `image_prop_custom_dimension`.
            'default' => 'full',
        ]
    );

    $this->add_responsive_control('team_align',
      [
          'label'         => __( 'Alignment', 'slope' ),
          'type'          => \Elementor\Controls_Manager::CHOOSE,
          'options'       => [
              'margin-right: auto;'      => [
                  'title'=> __( 'Left', 'slope' ),
                  'icon' => 'fa fa-align-left',
              ],
              'margin-left: auto; margin-right: auto;'    => [
                  'title'=> __( 'Center', 'slope' ),
                  'icon' => 'fa fa-align-center',
              ],
              'margin-left: auto;'     => [
                  'title'=> __( 'Right', 'slope' ),
                  'icon' => 'fa fa-align-right',
              ],
          ],
          'selectors'     => [
              '{{WRAPPER}} .team-member' => '{{VALUE}}',
          ],
      ]
    );

    $this->end_controls_section();

    // style - end

    // social icons style - start

    $this->start_controls_section(
      'team_icon_style',
      [
        'label' => __('Social icons', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
  );

    $this->add_control(
      'team_social_bg',
      [
        'label' => __('Background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .team-member .team-member-social' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );

    $this->start_controls_tabs( 'team_tabs' );
    
    $this->start_controls_tab(
        'team_social_normal',
        [
            'label' => __( 'Normal', 'slope' ),
        ]
    );

    $this->add_control(
        'button_social_bg_normal',
        [
          'label' => __('Circle color', 'slope'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .team-member-social ul li a' => 'background-color : {{VALUE}}'
          ]
          
        ]
    );

    $this->add_control(
      'button_social_color_normal',
      [
        'label' => __('Icon color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .team-member-social ul li a i' => 'color : {{VALUE}}'
        ]
        
      ]
    );
    
    $this->end_controls_tab();

    $this->start_controls_tab(
        'team_social_hover',
        [
            'label' => __( 'Hover', 'slope' ),
        ]
    );

    $this->add_control(
      'button_social_bg_hover',
      [
        'label' => __('Circle color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .team-member-social ul li a:hover' => 'background-color : {{VALUE}}'
        ]
        
      ]
  );

  $this->add_control(
    'button_social_color_hover',
    [
      'label' => __('Icon color', 'slope'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} .team-member-social ul li a:hover i' => 'color : {{VALUE}}'
      ]
      
    ]
  );

    $this->end_controls_tab();

    $this->end_controls_tabs();  

    $this->end_controls_section();

    // social icons style - start

  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();

    ?>
    <div class="team-member">
        <div class="team-member-image">
            <?php 
              echo Elementor\Group_Control_Image_Size::get_attachment_image_html(
                $settings, 
                'team_image_prop', 
                'team_image'
              );
            ?>
            <div class="team-member-social">
              <ul>
                <?php 
                  foreach($settings['team_social_repeater'] as $item):
                    $target = $item['team_social_link']['is_external'] ? ' target="_blank"' : '';
                    $nofollow = $item['team_social_link']['nofollow'] ? ' rel="nofollow"' : '';  
                    $url = $item['team_social_link']['url'] ? 'href='.$item['team_social_link']['url'] : '';
                ?>
                  <li>
                    <a <?php echo esc_attr( $url.' '.$target.' '.$nofollow ); ?>>
                      <?php 
                        \Elementor\Icons_Manager::render_icon( 
                          $item['team_social_icon'], 
                          [ 'aria-hidden' => 'true' ]
                        );
                      ?>
                    </a>
                  </li>
                <?php endforeach; ?>
              </ul>
            </div>
        </div>
        <div class="team-member-content">
            <h5><?php echo esc_html($settings['team_name']); ?></h5>
            <h6><?php echo esc_html($settings['team_designation']); ?></h6>
        </div>
    </div>
    <?php
  }
}
