<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class TestimonialSlider extends \Elementor\Widget_Base{

  public function get_name(){
    return 'testimonial_slope';
  }

  public function get_title(){
    return __( 'Testimonial Slider', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-quote-left';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // testimonials - start

    $this->start_controls_section(
      'testimonial_testimonial_section',
      [
        'label' => __('Testimonial', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
        'testimonial_image',
        [
            'label' => __( 'Choose Image', 'slope' ),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ]
    );

    $repeater->add_control(
      'testimonial_testimonial',
      [
        'label' => __('Testimonial', 'slope'),
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => ''
      ]
    );

    $repeater->add_control(
      'testimonial_name',
      [
        'label' => __('Name', 'slope'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => ''
      ]
    );

    $repeater->add_control(
      'testimonial_designation',
      [
        'label' => __('Designation', 'slope'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => ''
      ]
    );
    
    $this->add_control(
      'testimonial_slider_repeater',
      [
        'label' => __( 'Testmonial slides', 'slope' ),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'testimonial_image' => '',
            'testimonial_testimonial' => '',
            'testimonial_name' => '',
            'testimonial_designation' => ''
          ],
        ],
        'title_field' => __ ( 'Testmonial','slope' ),
      ]
    );

    $this->end_controls_section();

    // testimonials - end

    // slider options - start

    $this->start_controls_section(
      'testimonial_slider_options_section',
      [
        'label' => __('Slider options', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $this->add_control(
      'testimonial_autoplay',
      [
        'label' => __( 'Slider autoplay', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'yes', 'slope' ),
        'label_off' => __( 'no', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );
  
    $this->add_control(
      'testimonial_autoplay_delay',
      [
        'label' => __( 'Delay', 'slope' ),
        'description' => __('1000 represents 1 second', 'slope'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 60000,
        'step' => 500,
        'default' => 2000
      ]
    );
  
    $this->add_control(
      'testimonial_speed',
      [
        'label' => __( 'Speed', 'slope' ),
        'description' => __('1000 represents 1 second', 'slope'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 60000,
        'step' => 500,
        'default' => 2000
      ]
    );

    $this->end_controls_section();

    // slider options - end

    // navigation - start

    $this->start_controls_section(
      'testimonial_navigation_section',
      [
        'label' => __('Navigation', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $this->add_control(
      'testimonial_slider_navigation',
      [
        'label' => __( 'Show navigation', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'yes', 'slope' ),
        'label_off' => __( 'no', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'testimonial_slider_prev_icon',
      [
        'label' => __('Previous icon', 'slope'),
        'type' => \Elementor\Controls_Manager::ICONS,
        'condition' => ['testimonial_slider_navigation' => 'yes']
      ]
    );

    $this->add_control(
      'testimonial_slider_next_icon',
      [
        'label' => __('Next icon', 'slope'),
        'type' => \Elementor\Controls_Manager::ICONS,
        'condition' => ['testimonial_slider_navigation' => 'yes']
      ]
    );

    $this->end_controls_section();

    // navigation - end

    // testimonial style - start

    $this->start_controls_section(
      'testimonial_testimony_style',
      [
        'label' => __('Testimonial', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'testimonial_message_type',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .testimonial-content div',
      ]
    );
  
    $this->add_control(
      'testimonial_message_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .testimonial-content div' => 'color : {{VALUE}}'
        ]
        
      ]
    );

    $this->end_controls_section();

    // testimonial style - end

    // name style - start

    $this->start_controls_section(
      'testimonial_name_style',
      [
        'label' => __('Name', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'testimonial_author_type',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .testimonial-content h3',
      ]
    );
  
    $this->add_control(
      'testimonial_author_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .testimonial-content h3' => 'color : {{VALUE}}'
        ]
        
      ]
    );

    $this->end_controls_section();

    // name style - end

    // designation style - start

    $this->start_controls_section(
        'testimonial_style',
        [
          'label' => __('Designation', 'slope'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'testimonial_designation_type',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .testimonial-content h4',
      ]
    );

    $this->add_control(
      'testimonial_designation_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .testimonial-content h4' => 'color : {{VALUE}}'
        ]
        
      ]
    );

    $this->end_controls_section();

    // designation style - end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();

    $options = [
      'speed' =>  $settings['testimonial_speed'],
      'slidesPerView' => 1,
      'spaceBetween' => 0,    
      'breakpoints' => [
        '1024' => [ 'spaceBetween' => 30, 'slidesPerView' => 1 ],
        '0' => [ 'spaceBetween' => 20, 'slidesPerView' => 1 ]
      ]
    ];

    if ( $settings['testimonial_autoplay'] == 'yes' ) {
      $options['autoplay'] = array(
        'delay' => $settings['testimonial_autoplay_delay']
      );
    }

    if ($settings['testimonial_slider_navigation'] == 'yes') {
      $options['navigation'] = array(
        'nextEl' => '.slider--nav-'.$id.' .slider--nav-next',
        'prevEl' => '.slider--nav-'.$id.' .slider--nav-prev'
      );
    }

    ?>
    <div class="testimonial-slider">
      <div class="swiper-container slider-<?php echo esc_attr($id); ?>">
        <div class="swiper-wrapper">
          <?php foreach ($settings['testimonial_slider_repeater'] as $item): ?>
            <div class="swiper-slide testimonial-slide">
              <div class="testimonial-image">
                <?php 
                  echo 
                  \Elementor\Group_Control_Image_Size::get_attachment_image_html( 
                    $item, 
                    'thumbnail', 
                    'testimonial_image' 
                  ); 
                ?>
              </div>
              <div class="testimonial-content">
                <div>
                  <span>“</span>
                    <?php echo wp_kses( $item['testimonial_testimonial'], 'br-allowed' ); ?>
                    <span>”</span>
                </div>
                <h3><?php echo esc_html( $item['testimonial_name'] ); ?></h3>
                <h4><?php echo esc_html( $item['testimonial_designation'] ); ?></h4>
              </div>
            </div>
          <?php endforeach; ?>
        </div>
      </div>
      <div class="slider--nav slider--nav-<?php echo esc_attr($id); ?>">
        <?php if ($settings['testimonial_slider_navigation'] == 'yes'): ?>
        <div class="slider--nav-prev">
          <?php 
            \Elementor\Icons_Manager::render_icon( 
              $settings['testimonial_slider_prev_icon'], 
              [ 'aria-hidden' => 'true' ] 
            );
          ?>
        </div>
        <?php endif; ?>
        <h6 class="slider--nav-numbers slider--nav-numbers-<?php echo esc_attr($id); ?>">00 / 00</h6>
        <?php if ($settings['testimonial_slider_navigation'] == 'yes'): ?>
        <div class="slider--nav-next">
          <?php 
            \Elementor\Icons_Manager::render_icon( 
              $settings['testimonial_slider_next_icon'], 
              [ 'aria-hidden' => 'true' ] 
            );
          ?>
        </div>
        <?php endif; ?>
      </div>
    </div>
    <?php 
      slope_render_script($id, $options, true);
  }
}
