<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class TextList extends \Elementor\Widget_Base{

  public function get_name(){
    return 'textList_slope';
  }

  public function get_title(){
    return __( 'Text List', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-list';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // content - start

    $this->start_controls_section(
      'text_list_content_section',
      [
        'label' => __('Content', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
        'list_item',
        [
            'label' => __('Text', 'slope'),
            'label_block' => true,
            'type' => \Elementor\Controls_Manager::TEXT,
            'default' => ''
        ]
    );

    $repeater->add_control(
        'list_link',
        [
            'label' => __( 'Link', 'slope' ),
            'type' => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'slope' ),
            'show_external' => true,
            'default' => [
                'url' => '',
                'is_external' => true,
                'nofollow' => true,
            ],
        ]
    );

    $this->add_control(
        'list_item_repeater',
        [
          'label' => __( 'List', 'slope' ),
          'type' => \Elementor\Controls_Manager::REPEATER,
          'fields' => $repeater->get_controls(),
          'default' => [
            [
              'list_item' => '',
            ],
          ],
          'title_field' => __ ( 'List item','slope' ),
        ]
    );

    $this->add_control(
      'list_type',
      [
          'label' => __( 'List type', 'slope' ),
          'type' => \Elementor\Controls_Manager::SELECT,
          'default' => 'ul',
          'options' => [
              'ol'  => __( 'Ordered', 'slope' ),
              'ul'  => __( 'Unordered', 'slope' ),
          ],
      ]
    );

    $this->add_control(
      'list_preicon',
      [
        'label' => __('Icon prefix for list elements', 'slope'),
        'type' => \Elementor\Controls_Manager::ICONS,
        'condition' => ['list_type' => 'ul']
      ]
    );

    $this->end_controls_section();

    // content - end

    // style - start

    $this->start_controls_section(
      'text_list_styles_section',
      [
        'label' => __('Style', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_control(
      'list_size_preset',
      [
        'label' => __( 'Size preset', 'slope' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'large',
        'options' => [
          'text-list-large' => __( 'Large', 'slope' ),
          'text-list-medium' => __( 'Medium', 'slope' ),
        ],
      ]
    );

    $this->add_control(
      'list_color_preset',
      [
          'label' => __( 'Color preset', 'slope' ),
          'type' => \Elementor\Controls_Manager::SELECT,
          'default' => 'dark-1',
          'options' => [
              'dark-1'  => __( 'Dark-1', 'slope' ),
              'dark-2'  => __( 'Dark-2', 'slope' ),
              'light-1' => __( 'Light 1', 'slope' ),
              'light-2' => __( 'Light 2', 'slope' ),
          ],
      ]
    );

    $this->add_group_control(
        \Elementor\Group_Control_Typography::get_type(),
        [
            'name' => 'list_item_style',
            'label' => __('Typography', 'slope'),
            'selector' => '{{WRAPPER}} .text-list li, {{WRAPPER}} .text-list a',
        ]
    );

    $this->add_control(
      'list_item_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .text-list li' => 'color : {{VALUE}}',
          '{{WRAPPER}} .text-list a' => 'color : {{VALUE}}'
        ]
        
      ]
    );

    $this->add_control(
      'list_item_hover_bg',
      [
        'label' => __('Bar color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .text-list a::before' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );

  $this->end_controls_section();

  // style - end



  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();

    $class_list = ['text-list', $settings['list_size_preset'], $settings['list_color_preset']]

  ?>
    <div class="<?php echo esc_attr( implode( ' ', $class_list ) ); ?>">
        <<?php echo esc_html( $settings['list_type'] ); ?>>
          <?php foreach ( $settings['list_item_repeater'] as $item ): ?>
            <li>
                <?php if ( !empty( $item['list_link']['url'] ) ): 
                    $target = $item['list_link']['is_external'] ? ' target="_blank"' : '';
                    $nofollow = $item['list_link']['nofollow'] ? ' rel="nofollow"' : '';
                    $url = 'href='.esc_url($item['list_link']['url']);
                ?>
                  <a <?php echo esc_attr( $url.' '.$target.' '.$nofollow ); ?>>
                <?php endif; ?>
                
                <?php 
                  \Elementor\Icons_Manager::render_icon( 
                    $settings['list_preicon'], 
                    [ 'aria-hidden' => 'true' ]
                  );
                ?>
                <span>
                  <?php echo esc_html( $item['list_item'] ); ?>
                </span>

                <?php if ( !empty( $item['list_link']['url'] ) ): ?>
                </a>
                <?php endif; ?>
            </li>
          <?php endforeach; ?>
        </<?php echo esc_html( $settings['list_type'] ); ?>>
    </div>
    <?php
  }
}
