<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Video extends \Elementor\Widget_Base{

  public function get_name(){
    return 'video_slope';
  }

  public function get_title(){
    return __( 'Video', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-video';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    $this->start_controls_section(
      'video_content',
      [
        'label' => __('Content', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );


    $this->add_control(
        'video_url',
        [
        'label' => __('Video link', 'slope'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'description' => __('Enter the link for the self-hosted video', 'slope'),
        'default' => ''
        ]
    );

    $this->add_control(
      'video_autoplay',
      [
        'label' => __( 'Autoplay', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'Show', 'slope' ),
        'label_off' => __( 'Hide', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'video_muted',
      [
        'label' => __( 'Mute', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'Show', 'slope' ),
        'label_off' => __( 'Hide', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'video_loop',
      [
        'label' => __( 'Loop', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'Show', 'slope' ),
        'label_off' => __( 'Hide', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );


    $this->end_controls_section();

    $this->start_controls_section(
        'video_custom_style',
        [
          'label' => __('Custom', 'slope'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_responsive_control(
			'video_width',
			[
				'label' => __( 'Width', 'slope' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => [ 'px', '%', 'rem' ],
        'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
          ],
          'rem' => [
						'min' => 0,
						'max' => 100,
					]
				],
				'default' => [
					'unit' => '%',
					'size' => 100,
				],
				'selectors' => [
          //'{{WRAPPER}} .video_wrapper' => 'width: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} video' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
    );
    
    $this->add_responsive_control(
			'video_height',
			[
				'label' => __( 'Height', 'slope' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => [ 'px', '%', 'rem' ],
        'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
          ],
          'rem' => [
						'min' => 0,
						'max' => 100,
					]
				],
				'default' => [
					'unit' => 'rem',
					'size' => 81.9,
				],
				'selectors' => [
          //'{{WRAPPER}} .video_wrapper' => 'min-height: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} video' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

    $this->end_controls_section();
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();
    ?>
    
    <video 
    <?php echo esc_attr($settings['video_muted'] == 'yes' ? 'muted': ''); ?> 
    <?php echo esc_attr($settings['video_autoplay'] == 'yes' ? 'autoplay': ''); ?>
    playsinline
    preload="auto"
    id="<?php echo esc_attr($id); ?>" 
    >
      <source src="<?php echo esc_url($settings['video_url']); ?>" type="video/mp4">
    </video>
 
    <?php if ($settings['video_loop'] == 'yes'): ?>
    <script>
      (function($){
        "use strict";
        $('#<?php echo esc_attr($id); ?>').on('ended', function () {
          this.pause();
          this.currentTime = 0.44;
          this.play();
        });
      })(jQuery);
    </script>
    <?php endif; ?>
    <?php
  }

  protected function _content_template(){
    
  ?>

  <?php
  }
}
