<?php 
    get_header();

    // redux option name
    global $gfxpartner_slope;

    // build query for the posts
    $args = array(
            's' => get_search_query(),
            'post_type' => 'post',
            'post_status'    => 'publish',
            'paged' => get_query_var('paged')
    );

    $the_query = new WP_Query( $args );

    // determine if sidebar should be displayed or not, sidebar will appear by default
    $show_sidebar_archive = true;
    if (isset($gfxpartner_slope['show_sidebar_search'])) {
        $show_sidebar_archive = $gfxpartner_slope['show_sidebar_search'];
    }
    
    // determine sidebar location. default is on the right side
    $archive_sidebar_location = '2';
    if (isset($gfxpartner_slope['search_sidebar_location'])) {
        $archive_sidebar_location = $gfxpartner_slope['search_sidebar_location'];
    }

    // determine the corresponding bootstrap column for the content of the page
    $content_column = 'col-lg-8';
    // layout option for the blog post. default is list-1
    $post_layout = 'list';

    // if sidebar is not showing then
    if (!is_active_sidebar('search-sidebar')) {
        $content_column = 'col';
        $post_layout = 'grid';
    }

    // if sidebar location is left
    // if ($show_sidebar_archive && $archive_sidebar_location == '1') {
    //     $post_layout = 'list-1-left';
    // }

    $show_excerpt = true;
    // if excerpt is to be shown, change post layout variable
    if (isset($gfxpartner_slope['show_excerpt_search'])) {
        $show_excerpt = $gfxpartner_slope['show_excerpt_search'];
    }

    if ($show_excerpt) {
        $post_layout .= '-1';
    }

    $content_class = 'content-column';
    if ($show_sidebar_archive && $archive_sidebar_location == '1' && is_active_sidebar('search-sidebar')) {
        $content_class .= ' left-sidebar';
    } else if ($show_sidebar_archive && $archive_sidebar_location == '2' && is_active_sidebar('search-sidebar')) {
        $content_class .= ' right-sidebar';
    }

?>

<div class="search-result sidebar-page">
    <div class="container">
        <div class="row">
            <div class="col-lg-8">
                <?php 
                    // display heading if search yields posts
                    if ( $the_query->have_posts() ): 
                ?>
                <div class="heading-container">
                    <h5 class="heading heading-small light-2">
                            <?php echo esc_html__('Showing results for:', 'slope'); ?>
                    </h5>
                    <h1 class="heading heading-large dark-1">
                        <span><?php echo get_search_query(); ?></span>
                    </h1>
                </div>
                <?php
                    // if no posts are yielded by search, display error content
                    else: 
                        get_template_part('/inc/template/part', 'search-error');
                    endif; 
                ?>
            </div>
        </div>
        <?php if ( $the_query->have_posts() ): ?>
        <div class="row">
            <div class="col-lg-12">
                <div class="search-result--inner">
                    <div class="container">
                        <div class="row">
                            <?php
                                // display sidebar on the left side
                                if (
                                    $show_sidebar_archive && 
                                    $archive_sidebar_location == '1' && 
                                    is_active_sidebar('search-sidebar')
                                ):
                            ?>
                                <!--
                                left sidebar - start
                                -->
                                <div class="col-lg-4 sidebar-column">
                                    <div class="sidebar-column-wrapper">
                                        <ul class="widget widget-container">
                                            <?php dynamic_sidebar('search-sidebar'); ?>
                                        </ul>
                                    </div>
                                </div>
                                <!--
                                left sidebar - end
                                -->
                            <?php endif; // ending - left sidebar condition ?>

                            <div class="<?php echo esc_attr($content_column); ?>">
                                <div class="<?php echo esc_attr( $content_class ); ?>">
                                    <div class="blog-list">
                                        <div class="container">
                                            <div class="blog-list-container">
                                                <div class="row">
                                                <!--
                                                posts - start
                                                -->
                                                <?php 

                                                    if( $the_query->have_posts() ) : 
                                                        while( $the_query->have_posts() ) {
                                                            $the_query->the_post();

                                                            // get single post
                                                            get_template_part('inc/template/part', 'post', array(
                                                                'id' => get_the_ID(),
                                                                'blog_layout' => $post_layout
                                                            ));
                                                        } 
                                                        
                                                        // restore $post global 
                                                        wp_reset_postdata();         
                                                ?> 
                                                <!--
                                                posts - end
                                                -->
                                                    <?php
                                                        if ( !empty( get_previous_posts_link() ) || !empty( get_next_posts_link() ) ):
                                                    ?>
                                                    <!--
                                                    post pagination - start
                                                    -->
                                                    <div class="col-lg-11 <?php echo esc_attr($post_layout == 'list-1-left' ? 'offset-lg-1': ''); ?>">
                                                        <div class="pagination-container">
                                                            <?php 
                                                                $args =  array(
                                                                    'base'         => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
                                                                    'total'        => $the_query->max_num_pages,
                                                                    'current'      => max( 1, get_query_var( 'paged' ) ),
                                                                    'format'       => '?paged=%#%',
                                                                    'show_all'     => false,
                                                                    'type'         => 'list',
                                                                    'end_size'     => 2,
                                                                    'mid_size'     => 1,
                                                                    'prev_next'    => false,
                                                                    'add_args'     => false,
                                                                    'add_fragment' => '',
                                                                ) ;
                                                                echo paginate_links($args); 
                                                            ?>
                                                        </div>
                                                    </div>
                                                    <!--
                                                    post pagination - end
                                                    -->
                                                    <?php endif; ?>
                                                <?php endif; // ending - if( $the_query->have_posts() ) ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <?php
                                // display sidebar on the right side
                                if (
                                    $show_sidebar_archive &&
                                    $archive_sidebar_location == '2' &&
                                    is_active_sidebar('search-sidebar')
                                ):
                            ?>
                                <!--
                                right sidebar - start
                                -->
                                <div class="col-lg-4 sidebar-column">
                                    <div class="sidebar-column-wrapper">
                                        <ul class="widget widget-container">
                                            <?php dynamic_sidebar('search-sidebar'); ?>
                                        </ul>
                                    </div>
                                </div>
                                <!--
                                right sidebar - end
                                -->
                            <?php endif; // ending - right sidebar condition ?>

                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php endif; // ending - if ( $the_query->have_posts() ) ?>
    </div>
</div>
 
<?php get_footer(); ?>